@@ -129,7 +129,8 @@ def validate_adjacency(adj: torch.Tensor, n: Optional[int] = None):
         raise ValueError(f"Invalid adjacency matrix shape: {adj.shape}. expected: {(n, n)}")
 
     # check value range
-    adj = adj.coalesce()
+    if adj.is_sparse and not adj.is_sparse_csr:
+        adj = adj.coalesce()
     values = adj.values()
     if (values < 0.0).any() or (values > 1.0).any():
         raise ValueError(
@@ -137,8 +138,12 @@ def validate_adjacency(adj: torch.Tensor, n: Optional[int] = None):
         )
 
     # check column-sum
-    adj_sum = torch.sparse.sum(adj, dim=0).to_dense()
-    if not torch.allclose(adj_sum, torch.ones_like(adj_sum)):
+    if adj.is_sparse and not adj.is_sparse_csr:
+        adj_sum = torch.sparse.sum(adj, dim=0).to_dense()
+    else:
+        # hotfix until torch.sparse.sum is implemented
+        adj_sum = adj.t() @ torch.ones(adj.shape[0])
+    if not torch.allclose(adj_sum, torch.ones_like(adj_sum), rtol=1.0e-04):
         raise ValueError(f"Invalid column sum: {adj_sum}. expected 1.0")
 
 
@@ -307,7 +312,18 @@ def power_iteration(
     progress = tqdm(range(max_iter), unit_scale=True, leave=False, disable=not use_tqdm)
     for i in progress:
         # calculate x = (1 - alpha) * A.dot(x) + alpha * x0
-        x = torch.sparse.addmm(input=x0, sparse=adj, dense=x, beta=alpha, alpha=beta)
+        x = torch.sparse.addmm(
+            # dense matrix to be added
+            x0,
+            # sparse matrix to be multiplied
+            adj,
+            # dense matrix to be multiplied
+            x,
+            # multiplier for added matrix
+            beta=alpha,
+            # multiplier for product
+            alpha=beta,
+        )
         # note: while the adjacency matrix should already be row-sum normalized,
         #       we additionally normalize x to avoid accumulating errors due to loss of precision
         x = functional.normalize(x, dim=0, p=1)
